.. redirect-from:: /users/prev_whats_new/github_stats_3.5.1

.. _github-stats-3-5-1:

GitHub statistics for 3.5.1 (Dec 11, 2021)
==========================================

GitHub statistics for 2021/11/16 (tag: v3.5.0) - 2021/12/11

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 29 issues and merged 84 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/67?closed=1>`__

The following 17 authors contributed 123 commits.

* Antony Lee
* Constantine Evans
* David Stansby
* Elliott Sales de Andrade
* franzhaas
* Greg Lucas
* Hansin Ahuja
* Hood Chatham
* Jake Lishman
* Jody Klymak
* Matthias Bussonnier
* Ryan May
* Steffen Rehberg
* Sven Eschlbeck
* sveneschlbeck
* Thomas A Caswell
* Tim Hoffmann

GitHub issues and pull requests:

Pull Requests (84):

* :ghpull:`21926`: Backport PR #21913 on branch v3.5.x (Make colorbar boundaries work again)
* :ghpull:`21924`: Backport PR #21861 on branch v3.5.x (DOC: Small formatting improvement to set_markevery)
* :ghpull:`21913`: Make colorbar boundaries work again
* :ghpull:`21922`: Backport PR #21753 on branch v3.5.x (DOC: update anatomy of figure)
* :ghpull:`21861`: DOC: Small formatting improvement to set_markevery
* :ghpull:`21919`: Fix use_data_coordinates docstring
* :ghpull:`21912`: Backport PR #21900 on branch v3.5.x (Include test notebooks in test package)
* :ghpull:`21900`: Include test notebooks in test package
* :ghpull:`21908`: Backport PR #21834 on branch v3.5.x (MAINT Fix signature qhull version function )
* :ghpull:`21907`: Backport PR #21905 on branch v3.5.x (Fix image testing decorator in pytest importlib mode)
* :ghpull:`21906`: Backport PR #21773 on branch v3.5.x (FIX: Reset label of axis to center)
* :ghpull:`21834`: MAINT Fix signature qhull version function
* :ghpull:`21905`: Fix image testing decorator in pytest importlib mode
* :ghpull:`21773`: FIX: Reset label of axis to center
* :ghpull:`21902`: Backport PR #21884 on branch v3.5.x (FIX: be more careful about coercing unit-full containers to ndarray)
* :ghpull:`21884`: FIX: be more careful about coercing unit-full containers to ndarray
* :ghpull:`21899`: Backport PR #21859 on branch v3.5.x (Fix streamline plotting from upper edges of grid)
* :ghpull:`21859`: Fix streamline plotting from upper edges of grid
* :ghpull:`21896`: Backport PR #21890 on branch v3.5.x (Drop retina images when building PDF docs)
* :ghpull:`21891`: Backport PR #21887 on branch v3.5.x (Make figure target links relative)
* :ghpull:`21883`: Backport PR #21872 on branch v3.5.x (FIX: colorbars with NoNorm)
* :ghpull:`21872`: FIX: colorbars with NoNorm
* :ghpull:`21869`: Backport PR #21866 on branch v3.5.x (Shorten some inset_locator docstrings.)
* :ghpull:`21866`: Shorten some inset_locator docstrings.
* :ghpull:`21865`: Backport PR #21864 on branch v3.5.x (Delete "Load converter" example)
* :ghpull:`21864`: Delete "Load converter" example
* :ghpull:`21857`: Backport PR #21837 on branch v3.5.x (Display example figures in a single column)
* :ghpull:`21856`: Backport PR #21853 on branch v3.5.x (DOC: Fix Annotation arrow style reference example)
* :ghpull:`21853`: DOC: Fix Annotation arrow style reference example
* :ghpull:`21852`: Backport PR #21818 on branch v3.5.x (Fix collections coerce float)
* :ghpull:`21818`: Fix collections coerce float
* :ghpull:`21849`: Backport PR #21845 on branch v3.5.x (FIX: bbox subfigures)
* :ghpull:`21845`: FIX: bbox subfigures
* :ghpull:`21832`: Backport PR #21820 on branch v3.5.x (Drop setuptools-scm requirement in wheels)
* :ghpull:`21820`: Drop setuptools-scm requirement in wheels
* :ghpull:`21829`: Backport PR #21823 on branch v3.5.x (DOC: Misc rst syntax fixes)
* :ghpull:`21823`: DOC: Misc rst syntax fixes
* :ghpull:`21826`: Backport PR #21800 on branch v3.5.x (DOC: Update Basic Usage tutorial)
* :ghpull:`21814`: Manual backport of #21794
* :ghpull:`21812`: Backport #21641
* :ghpull:`21810`: Backport PR #21743 on branch v3.5.x (Clarify Annotation arrowprops docs)
* :ghpull:`21808`: Backport PR #21785 on branch v3.5.x (Fix ConciseDateFormatter offset during zoom)
* :ghpull:`21807`: Backport PR #21791 on branch v3.5.x (Refix check for manager presence in deprecated blocking_input.)
* :ghpull:`21806`: Backport PR #21663 on branch v3.5.x (Use standard subplot window in macosx backend)
* :ghpull:`21785`: Fix ConciseDateFormatter offset during zoom
* :ghpull:`21804`: Backport PR #21659 on branch v3.5.x (Fix PDF contents)
* :ghpull:`21791`: Refix check for manager presence in deprecated blocking_input.
* :ghpull:`21793`: Backport PR #21787 on branch v3.5.x (Fixes row/column mixup in GridSpec height_ratios documentation.)
* :ghpull:`21787`: Fixes row/column mixup in GridSpec height_ratios documentation.
* :ghpull:`21778`: Backport PR #21705 on branch v3.5.x (MNT: make print_figure kwarg wrapper support py311)
* :ghpull:`21779`: Backport PR #21751 on branch v3.5.x (FIX: manual colorbars and tight layout)
* :ghpull:`21777`: Backport PR #21758 on branch v3.5.x (FIX: Make sure a renderer gets attached to figure after draw)
* :ghpull:`21751`: FIX: manual colorbars and tight layout
* :ghpull:`21705`: MNT: make print_figure kwarg wrapper support py311
* :ghpull:`21758`: FIX: Make sure a renderer gets attached to figure after draw
* :ghpull:`21775`: Backport PR #21771 on branch v3.5.x (DOC: fix missing ref)
* :ghpull:`21770`: Backport of PR #21631 on v3.5.x
* :ghpull:`21765`: Backport PR #21741 on branch v3.5.x (Reduce do_3d_projection deprecation warnings in external artists)
* :ghpull:`21764`: Backport PR #21762 on branch v3.5.x (FIX: align_x/ylabels)
* :ghpull:`21741`: Reduce do_3d_projection deprecation warnings in external artists
* :ghpull:`21762`: FIX: align_x/ylabels
* :ghpull:`21759`: Backport PR #21757 on branch v3.5.x (Fix doc typo.)
* :ghpull:`21704`: FIX: deprecation of render keyword to do_3d_projection
* :ghpull:`21730`: Backport PR #21727 on branch v3.5.x (Doc fix colormap inaccuracy)
* :ghpull:`21663`: Use standard subplot window in macosx backend
* :ghpull:`21725`: Backport PR #21681 on branch v3.5.x (Bind subplot_tool more closely to target figure.)
* :ghpull:`21665`: Include test notebooks in test package
* :ghpull:`21721`: Backport PR #21720 on branch v3.5.x (Fix compiler configuration priority for FreeType build)
* :ghpull:`21720`: Fix compiler configuration priority for FreeType build
* :ghpull:`21715`: Backport PR #21714 on branch v3.5.x (DOC: note renaming of config.cfg.template to mplconfig.cfg.template)
* :ghpull:`21706`: Backport PR #21703 on branch v3.5.x (Changed the link to the correct citing example)
* :ghpull:`21691`: Backport PR #21686 on branch v3.5.x (FIX: colorbar for horizontal contours)
* :ghpull:`21689`: Backport PR #21676 on branch v3.5.x (Fix boundary norm negative)
* :ghpull:`21686`: FIX: colorbar for horizontal contours
* :ghpull:`21681`: Bind subplot_tool more closely to target figure.
* :ghpull:`21676`: Fix boundary norm negative
* :ghpull:`21685`: Backport PR #21658 on branch v3.5.x (Validate that input to Poly3DCollection is a list of 2D array-like)
* :ghpull:`21684`: Backport PR #21662 on branch v3.5.x (FIX: put newline in matplotlibrc when setting default backend)
* :ghpull:`21658`: Validate that input to Poly3DCollection is a list of 2D array-like
* :ghpull:`21662`: FIX: put newline in matplotlibrc when setting default backend
* :ghpull:`21651`: Backport PR #21626 on branch v3.5.x (Added the definition of Deprecation and made Deprecation Process clearer)
* :ghpull:`21626`: Added the definition of Deprecation and made Deprecation Process clearer
* :ghpull:`21137`: Small cleanups to colorbar.

Issues (29):

* :ghissue:`21909`: [Bug]: Matplotlib is unable to apply the boundaries in the colorbar after updating to 3.5.0
* :ghissue:`21654`: [Bug]: test_nbagg_01.ipynb not installed
* :ghissue:`21885`: [Bug]: test decorator breaks with new pytest importlib mode
* :ghissue:`21772`: [Bug]: cannot reset label of axis to center
* :ghissue:`21669`: [Bug]: Matplotlib 3.5 breaks unyt integration of error bars
* :ghissue:`21649`: [Bug]: Startpoints in streamplot fail on right and upper edges
* :ghissue:`21870`: [Bug]: Colormap + NoNorm only plots one color under ``matplotlib`` 3.5.0
* :ghissue:`21882`: [Bug]: Colorbar does not work for negative values with contour/contourf
* :ghissue:`21803`: [Bug]: using ``set_offsets`` on scatter object raises TypeError
* :ghissue:`21839`: [Bug]: Top of plot clipped when using Subfigures without suptitle
* :ghissue:`21841`: [Bug]: Wrong tick labels and colorbar of discrete normalizer
* :ghissue:`21783`: [MNT]: wheel of 3.5.0 appears to depend on setuptools-scm which appears to be unintentional
* :ghissue:`21733`: [Bug]: Possible bug on arrows in annotation
* :ghissue:`21749`: [Bug]: Regression on ``tight_layout`` when manually adding axes for colorbars
* :ghissue:`19197`: Unexpected error after using Figure.canvas.draw on macosx backend
* :ghissue:`13968`: ``ax.get_xaxis().get_minorticklabels()`` always returns list of empty strings
* :ghissue:`7550`: Draw not caching with macosx backend
* :ghissue:`21740`: [Bug]: unavoidable ``DeprecationWarning`` when using ``Patch3D``
* :ghissue:`15884`: DOC: Error in colormap manipulation tutorial
* :ghissue:`21648`: [Bug]: subplot parameter window appearing 1/4 size on macosx
* :ghissue:`21702`: [Doc]: Wrong link to the ready-made citation entry
* :ghissue:`21683`: [Bug]: add_lines broken for horizontal colorbars
* :ghissue:`21680`: [MNT]: macosx subplot parameters multiple windows
* :ghissue:`21679`: [MNT]: Close subplot_parameters window when main figure closes
* :ghissue:`21671`: [Bug]: 3.5.0 colorbar ValueError: minvalue must be less than or equal to maxvalue
* :ghissue:`21652`: [Bug]: ax.add_collection3d throws warning Mean of empty slice
* :ghissue:`21660`: [Bug]: mplsetup.cfg parsing issue
* :ghissue:`21668`: [Bug]: New plot directive error in 3.5.0
* :ghissue:`21393`: [Doc]: describe deprecation process more explicitly
